# -*- coding: utf-8 -*-

"""Top-level package for mlframe."""

__author__ = """Sam Stoltenberg"""
__email__ = 'sam@skelouse.com'
__version__ = '0.1.7'

from .mlframe import MLFrame
print("For convinent loading 'from mlframe import MLFrame")
